@@ -1,6 +1,6 @@
 /* The applet class which coordinates everything.
  *
- * Copyright (c) 2003, 04 Ole Laursen.
+ * Copyright (c) 2003, 04, 05 Ole Laursen.
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,12 +29,13 @@
 #include <gtkmm/eventbox.h>
 #include <gtkmm/window.h>
 #include <gtkmm/tooltips.h>
+#include <gtkmm/aboutdialog.h>
+
 #include <glibmm/ustring.h>
 
 #include <gconfmm/client.h>
 #include <gconfmm/entry.h>
 
-#include <libgnomeuimm/about.h>
 
 #include <panel-applet.h>
 
@@ -97,7 +98,7 @@ private:
   // data
   PanelApplet *panel_applet;
   Glib::RefPtr<Gdk::Pixbuf> icon;
-  std::auto_ptr<Gnome::UI::About> about;
+  std::auto_ptr<Gtk::AboutDialog> about;
   std::auto_ptr<View> view;
   std::auto_ptr<PreferencesWindow> preferences_window;
 
