@@ -30,14 +30,14 @@
 
 #include "canvas-view.hpp"
 
-
 class Bar;
 
 class BarView: public CanvasView
 {
 public:
-  BarView();
+  BarView(bool horizontal = true);
   ~BarView();
+  virtual bool is_horizontal();
   
 private:
   virtual void do_update();
@@ -51,6 +51,7 @@ private:
   bar_sequence bars;
   
   int draws_since_update;
+  bool horizontal;
 };
 
 #endif
