@@ -117,7 +117,9 @@ void ColumnGraph::draw(Gnome::Canvas::Canvas &canvas,
   pixbuf->fill(color & 0xFFFFFF00);
   
 
-  double max = std::max(monitor->max(), 0.000001); // avoid division by zero
+  double max = monitor->max();
+  if (max <= 0)
+    max = 0.0000001;
 
   // start from right
   double l = width - ColumnView::pixels_per_sample
