@@ -150,6 +150,9 @@ unsigned int random_between(unsigned int min, unsigned int max)
 void Flame::recompute_fuel()
 {
   int ratio = int(value / max * 255);
+
+  if (ratio > 255)
+    ratio = 255;
   
   if (next_refuel <= 0) {
     next_refuel = random_between(5, 20);
