@@ -59,7 +59,7 @@ private:
   
   // we need to save these values to compute the difference next time the
   // monitor is updated
-  guint64 total_time, nice_time, idle_time;
+  guint64 total_time, nice_time, idle_time, iowait_time;
 };
 
 
